@@ -7,12 +7,12 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.94_5';
+$VERSION = '0.95';
 
 
 # The VERSION of the distribution is sourced from this file, because
 # this module also loads the XS extension.
-our $VERSION = '0.94_5';
+our $VERSION = '0.95';
 use Carp 'croak';
 
 { use XSLoader;
@@ -21,8 +21,7 @@ use Carp 'croak';
   XSLoader::load 'POSIX::1003', $VERSION;
 }
 
-my $in_constant_table;
-BEGIN { $in_constant_table = qr/
+my $in_constant_table = qr/
    ^_CS_    # confstr
  | ^DN_     # fcntl
  | ^E(?!CHONL|XIT_) # errno   ECHONL in Termios, EXIT_ in Proc
@@ -44,8 +43,7 @@ BEGIN { $in_constant_table = qr/
  | ^UL_     # ulimit
  | ^WSAE    # errno (windows sockets)
  | _OK$     # access
- /x
-};
+ /x;
 
 
 sub import(@)
@@ -146,7 +144,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.94_5';
+$VERSION = '0.95';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
